@@ -5,6 +5,7 @@ from random import randint
 import re
 import urllib
 import os
+from datetime import datetime
 
 __author__ = "Arun KR (kra3) <the1.arun@gmail.com>"
 __license__ = "Simplified BSD"
@@ -15,6 +16,12 @@ RE_LOCALE = re.compile(r'(^|\s*,\s*)([a-zA-Z]{1,8}(-[a-zA-Z]{1,8})*)\s*(;\s*q\s*
 RE_GA_ACCOUNT_ID = re.compile(r'^(UA|MO)-[0-9]*-[0-9]*$')
 RE_FIRST_THREE_OCTETS_OF_IP = re.compile(r'^((\d{1,3}\.){3})\d{1,3}$')
 
+def convert_ga_timestamp(timestamp_string):
+    timestamp = float(timestamp_string)
+    if timestamp > ((2 ** 31) - 1):
+        timestamp /= 1000
+    return datetime.utcfromtimestamp(timestamp)
+
 def get_32bit_random_num():
     return randint(0, 0x7fffffff)
 
@@ -45,7 +52,7 @@ def generate_hash(tmpstr):
 
 def anonymize_ip(ip):
     if ip:
-        match = RE_FIRST_THREE_OCTETS_OF_IP.findall(ip)
+        match = RE_FIRST_THREE_OCTETS_OF_IP.findall(str(ip))
         if match:
             return '%s%s' % (match[0][0], '0')
 
@@ -107,15 +114,3 @@ def stringify(s, stype=None, fn=None):
                 except UnicodeDecodeError:
                     return s.decode('ascii', 'replace')
     return s
-
-def pyga_logger(obj, is_exception=False):
-    logger = logging.getLogger('pyga')
-    try:
-        txt = stringify(obj)
-        if txt:
-            if is_exception:
-                logger.exception('%s' %txt)
-            else:
-                logger.debug('%s' %txt)
-    except:
-        pass
