@@ -1,9 +1,5 @@
 import unittest
 from cPickle import loads, dumps
-import sys
-sys.path.insert(0, '..')
-
-from pyga.requests import Visitor
 
 
 class TestSerialize(unittest.TestCase):
@@ -12,6 +8,8 @@ class TestSerialize(unittest.TestCase):
         This will test if the unique_id is equals after deserialization
         even if it is not acessed before serialization
         """
+        from pyga.requests import Visitor
+
         visitor = Visitor()
         serialized_visitor = dumps(visitor)
         deserialized_visitor = loads(serialized_visitor)
